@@ -85,7 +85,7 @@ def slider(fn: Callable[[int], Any], min=0, max=10, step=1, id2index: Optional[C
 
     def on_id_jumper_change(_sender):
         assert id2index is not None
-        idx = id2index(id_jumper.value.trim())
+        idx = id2index(id_jumper.value.strip())
         if idx is not None:
             update_index(idx)
 
